@@ -3,7 +3,7 @@ gym.logger.set_level(40)
 import numpy as np
 from gym_collision_avoidance.envs import Config
 from gym_collision_avoidance.envs.wrappers import FlattenDictWrapper, MultiagentFlattenDictWrapper, MultiagentDummyVecEnv, MultiagentDictToMultiagentArrayWrapper
-from stable_baselines.common.vec_env.dummy_vec_env import DummyVecEnv
+from gym_collision_avoidance.envs.vec_env import DummyVecEnv
 
 def create_env():
     import tensorflow as tf
@@ -498,4 +498,9 @@ policies = {
         'checkpt_name': 'stage2.pth',
         'sensors': ['other_agents_states', 'laserscan']
         },
-    }
\ No newline at end of file
+    }
+
+if __name__ == '__main__':
+    env, one_env = create_env()
+    env.reset()
+    run_episode(env, one_env)
